@@ -7,7 +7,7 @@ from xml.etree import ElementTree
 
 import requests
 
-from rsapi import API_URL, LOGGER, DEFAULT_RETRIES, DEFAULT_TIMEOUT
+from rsapi import API_URL, USER_AGENT, LOGGER, DEFAULT_RETRIES, DEFAULT_TIMEOUT
 
 
 def request(path, _retries=DEFAULT_RETRIES, _timeout=DEFAULT_TIMEOUT, **query):
@@ -21,7 +21,7 @@ def request(path, _retries=DEFAULT_RETRIES, _timeout=DEFAULT_TIMEOUT, **query):
                 url,
                 timeout=_timeout,
                 headers={
-                    "User-Agent": "python-rsapi (Python RS API library)"
+                    "User-Agent": USER_AGENT,
                 }
             )
         except requests.exceptions.Timeout:
